#ifndef _CAMERAPROPS_H_
#define _CAMERAPROPS_H_

#include "SerialPort.h"
#include <Window.h>

#define B_CANCELPROPSWINDOW 'BW1'
#define B_ZOOM58 'BZ58'
#define B_ZOOM51 'BZ51'
#define B_ZOOM41 'BZ41'
#define B_ZOOM34 'BZ34'
#define B_ZOOM29 'BZ29'
#define B_ZOOMCL 'BZCL'
#define B_FLASHAUTO 'BFA'
#define B_FLASHON 'BFON'
#define B_FLASHOFF 'BFO'
#define B_FLASHAUTOFILL 'BAF'
#define B_FLASHFILL 'BFF'
#define B_LOWRESPIC 'LRP'
#define B_HIRESPIC 'HRP'
#define B_JPEGPIC 'JPP'
#define B_FPIXPIC 'FPP'
#define B_QUALGOOD 'QG'
#define B_QUALBEST 'QB'
#define B_QUALBETTER 'QBT'
#define B_DELAYTIMER 'BDT'
#define B_ERASEALL 'BEA'
#define B_SETCAMTIME 'SCT'
#define B_FORMATCARD 'FMT'

typedef enum{
		B_LOW,
		B_MED,
		B_FULL
} battstatus;			

typedef enum{
		LOW_RES,
		HI_RES
} resolution;

typedef enum{
		JPEG = 3,
		FPIX
} filetype;

typedef enum{
		Q_GOOD = 1,
		Q_BETTER,
		Q_BEST
} imagequality;

typedef enum{
		F_AUTO,
		F_FILL,
		F_OFF,
		F_AUTORED,
		F_FILLRED
} flashmode;

typedef enum{
		Z_58MM,
		Z_51MM,
		Z_41MM,
		Z_34MM,
		Z_29MM,
		Z_CLOSEUP
} zoommode;

class cameraprops : public BWindow
{
public:
		cameraprops(BRect rect, BSerialPort* ComPort);
		virtual bool	QuitRequested();
		virtual void	MessageReceived(BMessage* message);
private:
	status_t updateCameraStatusInfo();
	void receivepacket(unsigned char* buffer, int& length);
	int setResolution(resolution res);
	int setFileFormat(filetype ftype);
	int setImageQuality(imagequality quality);
	int setFlashMode(flashmode flash);
	int setShutterDelay(bool delay);
	int setZoom(zoommode zoom);
	int eraseAllImages();
	int setTime();

	BSerialPort *ComPort;
		BView* propsview;
	BRadioButton *radioButton_L2S111;
	BRadioButton *radioButton_L2S112;
	BRadioButton *radioButton_L2S113;
	BRadioButton *radioButton_L2S114;
	BRadioButton *radioButton_L2S115;
	BRadioButton *radioButton_L2S116;
	BRadioButton *radioButton_L2S151;
	BRadioButton *radioButton_L2S152;
	BRadioButton *radioButton_L2S153;
	BRadioButton *radioButton_L2S154;
	BRadioButton *radioButton_L2S155;
	BRadioButton *radioButton_L2S191;
	BRadioButton *radioButton_L2S192;
	BRadioButton *radioButton_L2S171;
	BRadioButton *radioButton_L2S172;
	BRadioButton *radioButton_L2S141;
	BRadioButton *radioButton_L2S142;
	BRadioButton *radioButton_L2S143;
	BCheckBox *checkBox_L2S18;

	zoommode zoomposition;
	imagequality quality;
	flashmode flashsetting;
	resolution cameraresolution;
	filetype camerafiletype;
	bool timermode;
	bool cardATA;
	bool cardwriteprotect;
	bool cardillegal;
	bool cardformatted;
	bool cardopen;
	char cardid[11];
	char cameraid[32];
};

#endif
