#include "level1.h"
#include "level2.h"
#include "preferences.h"
#include "comms.h"
#include <iostream.h>

int get_BDCP_API_Revision(void)
{
	return(2);
}

void getPluginVersion(version_info &ver)
{
	ver.major = 2;
	ver.middle = 0;
	ver.minor = 0;
	ver.variety = 0;
	ver.internal = 0;
	sprintf(ver.short_info,"Copyright GWS 2000");
	sprintf(ver.long_info,"BDCP Kodak DC Range Plugin");
}

void getSupportedCameras(vector<string> & listofcams)
{
	listofcams.push_back("Kodak DC210 Digital Zoom Camera");
	listofcams.push_back("Kodak DC210+ Digital Zoom Camera");
}

status_t openCamera(void)
{
	status_t res;
	LoadSettingsFromFile();
	haveigotfilenames = false;
	unsigned char* buffer = new unsigned char[1];
	ComPort = new BSerialPort();
	ComPort->SetDataRate(B_9600_BPS);
	ComPort->SetFlowControl(0);
	ComPort->SetBlocking(true);
	ComPort->SetTimeout(3000000);
	res = ComPort->Open(serialportsetting.String());
	if (res < B_NO_ERROR)
		return(B_ERROR);
	switch(speed)
	{
		case B_9600_BPS:
		{
			ComPort->Write("\x41\x00\x96\x00\x00\x00\x00\x1A",8);
			break;
		}
		case B_19200_BPS:
		{
			ComPort->Write("\x41\x00\x19\x20\x00\x00\x00\x1A",8);
			break;
		}
		case B_38400_BPS:
		{
			ComPort->Write("\x41\x00\x38\x40\x00\x00\x00\x1A",8);
			break;
		}
		case B_57600_BPS:
		{
			ComPort->Write("\x41\x00\x57\x60\x00\x00\x00\x1A",8);
			break;
		}
		case B_115200_BPS:
		{
			ComPort->Write("\x41\x00\x11\x52\x00\x00\x00\x1A",8);
			break;
		}
		default:
		{
			ComPort->Write("\x41\x00\x11\x52\x00\x00\x00\x1A",8);
			break;
		}
	}
	ComPort->Read(buffer,1);
	while (buffer[0] == 0xf0) 
		ComPort->Read(buffer,1);
	if (buffer[0] == 0xe2)
		return(B_ERROR);
	else if (buffer[0] == 0xd1)
	{
		snooze(100000);
		ComPort->SetDataRate(speed);
	}
	return(B_NO_ERROR);
}

status_t closeCamera(void)
{
	unsigned char* buffer = new unsigned char[1];
	ComPort->Write("\x41\x00\x96\x00\x00\x00\x00\x1A",8);
	ComPort->Read(buffer,1);
	while (buffer[0] == 0xf0) 
		ComPort->Read(buffer,1);
	if (buffer[0] == 0xe2)
		return(B_ERROR);
	else if (buffer[0] == 0xd1)
		ComPort->SetDataRate(B_9600_BPS);
	ComPort->Close();
	SaveSettingsToFile();
	return(B_NO_ERROR);
}

status_t getNumberofPics(int &number)
{
	haveigotfilenames = false;
	int len = 256;
	unsigned char *buffer = new unsigned char[256];
	ComPort->Write("\x7F\x00\x00\x00\x00\x00\x00\x1A",8);
	ComPort->Read(buffer,1);
	while (buffer[0] == 0xf0) 
		ComPort->Read(buffer,1);
	if (buffer[0] == 0xe2)
		return(B_ERROR);
	else if (buffer[0] == 0xd1)
	{
		ComPort->Read(buffer,1);
		receivepacket(buffer,len, true);
		number = (buffer[56] << 8) + buffer[57];
		ComPort->Read(buffer,1);
		while (buffer[0] == 0xf0) 
			ComPort->Read(buffer,1);
	if (buffer[0] == 0x00)
		{
			snooze(50000);
			return(B_NO_ERROR);
			}
		else
			return(B_ERROR);
	}
	else
		return(B_ERROR);
}

status_t setCurrentPicture(int picturenum)
{
	currentpicturenumber = picturenum;
	return(B_NO_ERROR);
}

status_t downloadPicture(BPath savedir)
{
	int receivelength = 1024;
	unsigned char *buffer = new unsigned char[2000];
	if (haveigotfilenames == false)
		if (getfiledata() < B_NO_ERROR)
			return(B_ERROR);
	map<int, char*>::iterator pname;
	pname = imagenames.find(currentpicturenumber);
	char* filename = new char[255];
	sprintf(filename, "%s", pname->second);
	savedir.Append(filename);
	BFile* file = new BFile(savedir.Path(), B_WRITE_ONLY | B_CREATE_FILE | B_ERASE_FILE);
	char* temp2;
	ComPort->Write("\x64\x00", 2);
	temp2 = (char*)(currentpicturenumber >> 8);
	ComPort->Write(&temp2,1);
	temp2 = (char*)(currentpicturenumber >> 0);
	ComPort->Write(&temp2,1);
	ComPort->Write("\x00",1);
	ComPort->Write("\x00\x00\x1A",3);
	ComPort->Read(buffer,1);
	while (buffer[0] == 0xf0) 
		ComPort->Read(buffer,1);
	if (buffer[0] == 0xe2)
		return(B_ERROR);
	else if (buffer[0] == 0xd1)
	{
		ComPort->Read(buffer,1);
		do 
		{
			if (msgtarget != NULL)
			{
				BMessage *msg;
				msg = new BMessage(MSG_UPDATEBAR);
				msg->AddFloat("updateby", (float)receivelength);
				msgtarget->PostMessage(msg);
				delete msg;
			}
			receivepacket(buffer,receivelength, true);
			file->Write(buffer,receivelength);
			ComPort->Read(buffer,1);
			while (buffer[0] == 0xf0) 
				ComPort->Read(buffer,1);
		} while (buffer[0] == 0x01);
		if (buffer[0] == 0x00)
		{
			snooze(50000);
			return(B_NO_ERROR);
		}
		else
			return(B_ERROR);
	}
	else
		return(B_ERROR);
}

